@@ -8,6 +8,7 @@ import yaml
 from minio import Minio
 from minio.error import MinioException
 from pythonjsonlogger import jsonlogger
+from telegraf.client import TelegrafClient
 
 logger = logging.getLogger()
 
@@ -19,8 +20,6 @@ logHandler.setFormatter(formatter)
 logger.addHandler(logHandler)
 
 
-
-
 try:
     import picamera
 except ImportError:
@@ -47,12 +46,20 @@ CAMERA_SHUTTER_SPEED = int(os.environ.get("CAMERA_SHUTTER_SPEED", 0))
 CAMERA_H_FLIP = os.environ.get("CAMERA_H_FLIP", 0)
 CAMERA_V_FLIP = os.environ.get("CAMERA_V_FLIP", 0)
 
+TELEGRAF_HOST = os.environ.get("TELEGRAF_HOST", 'localhost')
+
+
+def emit(name, values, tags=None):
+    client = TelegrafClient(host=TELEGRAF_HOST, port=8092)
+    client.metric(name, values, tags=tags)
+
 
 def next_timeslot(now):
     return now + (PERIOD - (now % PERIOD))
 
 
 def capture_loop():
+    logger.setLevel(level=logging.DEBUG)
     logger.info("starting capture")
     try:
         with picamera.PiCamera() as camera:
@@ -74,23 +81,24 @@ def capture_loop():
                 timeslot += PERIOD
             logger.info("going to sleep for a bit %s", sleep_time)
             time.sleep(sleep_time)
-
             # camera.start_preview()
             video_start_time = datetime.datetime.fromtimestamp(timeslot)
             name = f'/out/video-{video_start_time:%Y_%m_%d_%H_%M-%S}.h264'
             camera.start_recording(name, format='h264', intra_period=INTRA_PERIOD, bitrate=BITRATE)
+            emit("camera_capture", {"video_start": 1, "origin": 1, "split": 0})
             camera.wait_recording(PERIOD - 0.001)
             while True:
                 timeslot += PERIOD
                 video_start_time = datetime.datetime.fromtimestamp(timeslot)
                 name = f'/out/video-{video_start_time:%Y_%m_%d_%H_%M-%S}.h264'
+                logger.info("recording started", extra={"metric_tag": "video_start", "video_start_time": f"{video_start_time:%Y_%m_%d_%H_%M-%S}"})
+                emit("camera_capture", {"video_start": 1, "origin": 0, "split": 1})
                 camera.split_recording(name, format='h264', intra_period=INTRA_PERIOD, bitrate=BITRATE)
                 delay = timeslot + PERIOD - time.time()
                 logger.info("waiting %s", delay)
                 camera.wait_recording(delay)
     except Exception as e:
-        logger.info(e)
-
+        logger.error(e)
 
 
 def get_next_file():
@@ -146,7 +154,8 @@ def upload_loop():
                 except Exception as ffmpeg_err:
                     logger.exception(ffmpeg_err)
                     logger.exception("ffmpeg_err %s", name)
-                logger.info('repackage took %s', (datetime.datetime.now() - start).total_seconds())
+                dur = (datetime.datetime.now() - start).total_seconds()
+                logger.info('repackage took %s', dur)
                 time.sleep(1)
                 ts = name[11:-5]
                 obj_name = (f'{DEVICE_ID}/{ts}.mp4').replace("_", "/")
@@ -156,10 +165,14 @@ def upload_loop():
                                         "ts": ts,
                                         "duration": f"{PERIOD}s",
                                         })
+                moved = 1
+                logger.info("upload successful", extra={"metric_tag": "video_moved", "video_start_time": ts})
                 os.remove(name)
                 os.remove(mp4_name)
             except Exception as err:
+                moved = 0
                 logger.exception(err)
                 logger.exception("failed to process %s", name)
+            emit("camera_move", {"ffmpeg_time_seconds": dur, "moved_to_control": moved})
         else:
             time.sleep(2)
